---
theme: default
paginate: true
title: Understanding a computer
---

# Understanding a computer

[![cc_by_sa](./img/cc_by_sa.png)](http://creativecommons.org/licenses/by-sa/4.0/)

Objective: understand the relations between the different components of a computer

---

# Which parts are necessary to define a computer ?


---

# Computer model: universal Turing machine


![width:20% height:20%](./img/lego_turing_machine.jpg)

---

# Computer components

## CPU (Central Processing Unit)
![CPU](./img/amd-ryzen-7-1700-cpu-inhand1-2-1500x1000.jpg)

## Memory

### RAM (Random Access Memory)
![RAM](./img/220px-Swissbit_2GB_PC2-5300U-555.jpg)

### HDD (Hard Disk Drive) / SSD (Solid-State Drive) 
![HDD](./img/220px-Laptop-hard-drive-exposed.jpg)
![SSD](./img/220px-SSD_Samsung_960_PRO_512GB_-_front_and_back_-_2018-05-27.jpg)

## Motherboard
![motherboard](./img/motherboard.jpg)

## GPU (Graphical Processing Unit)
![GPU](./img/foundation-100046736-orig.jpg)

## Alimentation
![Alim](./img/LD0003357907_2.jpg)

---

# As simple as a Turing machine ?

![universal_truing_machine](./img/universal_truing_machine.png)

- A tape divided into cells, one next to the other. Each cell contains a symbol from some finite alphabet.
- A head that can read and write symbols on the tape and move the tape left and right one (and only one) cell at a time.
- A state register that stores the state of the Turing machine, one of finitely many. Among these is the special start state with which the state register is initialized.
- A finite table of instructions that, given the state the machine is currently in and the symbol it is reading on the tape, tells the machine what to do.

---

# Basic Input Output System (BIOS)

> Used to perform hardware initialization during the booting process (power-on startup), and to provide runtime services for operating systems and programs.

- comes pre-installed on a personal computer's system board
- the first software to run when powered on
- in modern PCs initializes and tests the system hardware components, and loads a boot loader from a mass memory device

---

#  Unified Extensible Firmware Interface (UEFI)

Advantages:

- Ability to use large-disk partitions (over 2 TB) with a GUID Partition Table (GPT)
- CPU-independent architecture
- CPU-independent drivers
- Flexible pre-OS environment, including network capability
- Modular design
- Backward and forward compatibility

Disadvantages:

- More complex

---

# Operating System (OS)

> A system software that manages computer hardware, software resources, and provides common services for computer programs.

- The first thing loaded by the BIOS/UEFI
- The first thing on the tape of a Turing machine

## Kernel
> The kernel provides the most basic level of control over all of the computer's hardware devices. It manages memory access for programs in the RAM, it determines which programs get access to which hardware resources, it sets up or resets the CPU's operating states for optimal operation at all times, and it organizes the data for long-term non-volatile storage with file systems on such media as disks, tapes, flash memory, etc.

![Kernel](./img/220px-Kernel_Layout.svg.png)

---

# UNIX

> Unix is a family of multitasking, multiuser computer operating systems that derive from the original AT&T Unix,

[![Unix history](./img/1920px-Unix_timeline.en.svg.png)](https://upload.wikimedia.org/wikipedia/commons/7/77/Unix_history-simple.svg)

The ones you are likely to encounter:
- [macOS](https://en.wikipedia.org/wiki/MacOS)
- [BSD (Berkeley Software Distribution) variant](https://www.freebsd.org/)
- [GNU/Linux](https://www.kernel.org/)

The philosophy of UNIX is to have a large number of small software which do few things but to them well.

# GNU/Linux

Linux is the name of the kernel which software, to get a full OS, Linux is part of the [GNU Project](https://www.gnu.org/).

The GNU with Richard Stallman introduced the notion of Free Software:
1. The freedom to run the program as you wish, for any purpose.
2. The freedom to study how the program works, and change it so it does your computing as you wish. Access to the source code is a precondition for this.
3. The freedom to redistribute copies so you can help others.
4. The freedom to distribute copies of your modified versions to others. By doing this you can give the whole community a chance to benefit from your changes. Access to the source code is a precondition for this.

![Richard Stallman](https://audio-video.gnu.org/video/TEDxGE2014_Stallman05_LQ.webm)

You can find a [list of software licenses](https://www.gnu.org/licenses/license-list.html)

# (First) step with GNU/Linux

You first need to connect to [https://biosphere.france-bioinformatique.fr/](https://biosphere.france-bioinformatique.fr/).

Go to [RAINBio the catalogue of appliances](https://biosphere.france-bioinformatique.fr/catalogue/) and start the [UNIX Biocomputing](https://biosphere.france-bioinformatique.fr/catalogue/appliance/173/) appliance. An appliance is a virtual machine with preinstalled software.

Then go to the [myVM tab](https://biosphere.france-bioinformatique.fr/cloud/) and wait for your appliance to start.

Then click on the link **Params** to get your login and password.
![Params](ifb_params.png)

You can then open the **https** link.

And go to the next session [2 first steps in a terminal.](2_first_steps_in_a_terminal.html)



